package t::DB::Row::Author;
use Mouse v2.4.5;
extends qw/t::DB::Row/;

1;
__END__
